==> weld-servlet-shaded-3.1.1.Final-sources.jar: org/jboss/weld/module/web/el/ELCreationalContext.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.module.web.el;

import org.jboss.weld.contexts.CreationalContextImpl;

import javax.enterprise.context.spi.Contextual;
import java.util.HashMap;
import java.util.Map;

class ELCreationalContext<T> extends CreationalContextImpl<T> {

    private static final long serialVersionUID = -8337917208165841779L;

    private final Map<String, Object> expressionLocalDependentInstances;

    public ELCreationalContext(Contextual<T> contextual) {
        super(contextual);
        this.expressionLocalDependentInstances = new HashMap<String, Object>();
    }

    public void registerDependentInstanceForExpression(String name, Object value) {
        expressionLocalDependentInstances.put(name, value);
    }

    public Object getDependentInstanceForExpression(String name) {
        return expressionLocalDependentInstances.get(name);
    }

}

==> weld-servlet-shaded-5.1.2.Final-sources.jar: org/jboss/weld/module/web/el/ELCreationalContext.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.module.web.el;

import java.util.HashMap;
import java.util.Map;

import jakarta.enterprise.context.spi.Contextual;

import org.jboss.weld.contexts.CreationalContextImpl;

class ELCreationalContext<T> extends CreationalContextImpl<T> {

    private static final long serialVersionUID = -8337917208165841779L;

    private final Map<String, Object> expressionLocalDependentInstances;

    public ELCreationalContext(Contextual<T> contextual) {
        super(contextual);
        this.expressionLocalDependentInstances = new HashMap<String, Object>();
    }

    public void registerDependentInstanceForExpression(String name, Object value) {
        expressionLocalDependentInstances.put(name, value);
    }

    public Object getDependentInstanceForExpression(String name) {
        return expressionLocalDependentInstances.get(name);
    }

}
